@@ -24,6 +24,7 @@ from lightbulb import context
 from lightbulb import converters
 from lightbulb import cooldowns
 from lightbulb import errors
+from lightbulb import events
 from lightbulb import help
 from lightbulb import plugins
 from lightbulb import stringview
@@ -34,6 +35,7 @@ from lightbulb.commands import *
 from lightbulb.context import *
 from lightbulb.converters import *
 from lightbulb.cooldowns import *
+from lightbulb.events import *
 from lightbulb.help import *
 from lightbulb.plugins import *
 from lightbulb.stringview import *
@@ -48,6 +50,7 @@ __all__: typing.Final[typing.List[str]] = [
     *context.__all__,
     *stringview.__all__,
     *help.__all__,
+    *events.__all__,
 ]
 
-__version__ = "0.0.41"
+__version__ = "0.0.43"
