@@ -17,8 +17,9 @@
 # along with Lightbulb. If not, see <https://www.gnu.org/licenses/>.
 from __future__ import annotations
 
-__all__: typing.Final[typing.List[str]] = ["Bot"]
+__all__: typing.Final[typing.List[str]] = ["Bot", "when_mentioned_or"]
 
+import asyncio
 import collections
 import functools
 import importlib
@@ -33,6 +34,7 @@ from multidict import CIMultiDict
 from lightbulb import commands
 from lightbulb import context
 from lightbulb import errors
+from lightbulb import events
 from lightbulb import help as help_command
 from lightbulb import plugins
 from lightbulb import stringview
@@ -40,8 +42,58 @@ from lightbulb import stringview
 _LOGGER = logging.getLogger("lightbulb")
 
 
-async def _return_prefix(
-    _, __, *, prefixes: typing.Union[str, typing.List[str], typing.Tuple[str]]
+def when_mentioned_or(prefix_provider):
+    """
+    Helper function which allows the bot's mentions to be used as the command prefix, as well
+    as any other prefix(es) passed in or supplied by the ``prefix_provider``.
+
+    Args:
+        prefix_provider: An object that is a prefix, contains prefixes, or returns prefixes.
+
+    Example:
+
+        .. code-block:: python
+
+            # The below are all valid
+            bot = lightbulb.Bot(prefix=lightbulb.when_mentioned_or("!"), ...)
+
+            bot = lightbulb.Bot(prefix=lightbulb.when_mentioned_or(["!", "?"]), ...)
+
+            # Using only mentions as the prefix
+            bot = lightbulb.Bot(prefix=lightbulb.when_mentioned_or(None), ...)
+
+            # Using with a get_prefix function
+            def get_prefix(bot, message):
+                # Do something to get the prefixes
+                return prefixes
+
+            bot = lightbulb.Bot(prefix=lightbulb.when_mentioned_or(get_prefix), ...)
+    """
+
+    async def get_prefixes(bot, message):
+        mentions = [f"<@{bot.me.id}> ", f"<@!{bot.me.id}> "]
+
+        if callable(prefix_provider):
+            prefixes = prefix_provider(bot, message)
+            if inspect.iscoroutine(prefixes) or isinstance(prefixes, asyncio.Future):
+                prefixes = await prefixes
+        else:
+            prefixes = prefix_provider
+
+        if isinstance(prefixes, str):
+            return mentions + [prefixes]
+        elif isinstance(prefixes, typing.Iterable):
+            return mentions + list(prefixes)
+        elif prefixes is None:
+            return mentions
+        else:
+            return mentions + [prefix async for prefix in prefixes]
+
+    return get_prefixes
+
+
+def _return_prefix(
+    _, __, *, prefixes: typing.Union[str, typing.Iterable[str]]
 ) -> typing.Union[str, typing.List[str], typing.Tuple[str]]:
     return prefixes
 
@@ -593,9 +645,14 @@ class Bot(hikari.Bot):
         self, command: commands.Command, context: context.Context, args: typing.List[str],
     ) -> None:
         try:
+            await self.dispatch(events.CommandInvocationEvent(app=self, command=command, context=context))
+
             if not await self._evaluate_checks(command, context):
                 return
 
+            if (before_invoke := command._before_invoke) is not None:
+                await before_invoke(context)
+
             (before_asterisk, param_name,) = command.arg_details._args_and_name_before_asterisk()
             args = self._concatenate_args(args, command)
 
@@ -624,14 +681,31 @@ class Bot(hikari.Bot):
                     )
                 else:
                     await command.invoke(context, *args[:before_asterisk])
+
+            if (after_invoke := command._after_invoke) is not None:
+                await after_invoke(context)
+
+            await self.dispatch(events.CommandCompletionEvent(app=self, command=command, context=context))
         except errors.CommandError as ex:
-            error_event = errors.CommandErrorEvent(
+            error_event = events.CommandErrorEvent(
                 app=self, exception=ex, context=context, message=context.message, command=command
             )
 
             if command._error_listener is not None:
                 await command._error_listener(error_event)
-            if self.get_listeners(errors.CommandErrorEvent, polymorphic=True):
+            if self.get_listeners(events.CommandErrorEvent, polymorphic=True):
+                await self.dispatch(error_event)
+            else:
+                raise
+        except Exception as ex:
+            new_ex = errors.CommandInvocationError("An error occurred during command invocation.", original=ex)
+            error_event = events.CommandErrorEvent(
+                app=self, exception=new_ex, context=context, message=context.message, command=command
+            )
+
+            if command._error_listener is not None:
+                await command._error_listener(error_event)
+            if self.get_listeners(events.CommandErrorEvent, polymorphic=True):
                 await self.dispatch(error_event)
             else:
                 raise
@@ -639,14 +713,21 @@ class Bot(hikari.Bot):
     def _concatenate_args(self, args: typing.List[str], command: commands.Command):
         # Concatenates arguments for last argument (after asterisk sign)
         new_args = args
-        (before_asterisk, param_name,) = command.arg_details._args_and_name_before_asterisk()
+        before_asterisk, param_name = command.arg_details._args_and_name_before_asterisk()
+        default = command.arg_details._get_default_values()
 
         if before_asterisk < len(args) and not command.arg_details.has_max_args and param_name is not None:
+
             new_args = [
                 *args[:before_asterisk],
                 " ".join(args[before_asterisk:]),
             ]
 
+        elif before_asterisk == len(args) and not command.arg_details.has_max_args and param_name is not None:
+            if default[-1] != inspect.Parameter.empty:
+
+                new_args = [*args, default[-1]]
+
         return new_args
 
     async def handle(self, event: hikari.MessageCreateEvent) -> None:
@@ -692,9 +773,9 @@ class Bot(hikari.Bot):
 
         if invoked_with not in self._commands:
             ex = errors.CommandNotFound(invoked_with)
-            error_event = errors.CommandErrorEvent(app=self, exception=ex, message=event.message)
+            error_event = events.CommandErrorEvent(app=self, exception=ex, message=event.message)
 
-            if self.get_listeners(errors.CommandErrorEvent, polymorphic=True):
+            if self.get_listeners(events.CommandErrorEvent, polymorphic=True):
                 await self.dispatch(error_event)
                 return
             else:
