@@ -32,16 +32,16 @@ import inspect
 import logging
 import typing
 
+import hikari
 from multidict import CIMultiDict
 
 from lightbulb import context
 from lightbulb import converters
 from lightbulb import cooldowns
 from lightbulb import errors
+from lightbulb import events
 
 if typing.TYPE_CHECKING:
-    import hikari
-
     from lightbulb import plugins
 
 _LOGGER = logging.getLogger("lightbulb")
@@ -114,6 +114,8 @@ class ArgInfo:
     """The type annotation of the argument."""
     required: bool
     """Whether or not the argument is required during invocation."""
+    default: typing.Any
+    """Default value for an argument."""
 
 
 class SignatureInspector:
@@ -134,8 +136,7 @@ class SignatureInspector:
         self.max_args = sum(not arg.ignore for arg in self.args.values())
         self.min_args = sum(not arg.ignore and arg.required for arg in self.args.values())
         self.has_max_args = not any(
-            a.kind == inspect.Parameter.VAR_POSITIONAL
-            or (a.kind == inspect.Parameter.KEYWORD_ONLY and a.default is a.empty)
+            a.kind == inspect.Parameter.VAR_POSITIONAL or a.kind == inspect.Parameter.KEYWORD_ONLY
             for a in inspect.signature(command._callback).parameters.values()
         )
 
@@ -149,8 +150,9 @@ class SignatureInspector:
 
         argtype = arg.kind
         annotation = arg.annotation
-        required = (arg.default is arg.empty) or (arg.kind == 3)  # var positional
-        return ArgInfo(ignore, argtype, annotation, required)
+        required = ((arg.default is arg.empty) or (arg.kind == 3)) and arg.kind != 2  # keyword-only not required
+        default = arg.default
+        return ArgInfo(ignore, argtype, annotation, required, default)
 
     def _args_and_name_before_asterisk(self):
         args_num = 0
@@ -175,7 +177,8 @@ class SignatureInspector:
         # Check if number or *, args is bigger than 1 and throw error if yes
         if len(self.args) - args_num > 1:
             raise TypeError(
-                f"Number of arguments after * (asterisk) symbol in command {self.command._callback.__name__} has to be smaller or equal 1."
+                f"Number of arguments after * (asterisk) symbol in command {self.command._callback.__name__} is {len(self.args) - args_num}"
+                f" but has to be smaller or equal 1."
             )
 
         args_num -= 1  # because of the ctx arg
@@ -184,6 +187,10 @@ class SignatureInspector:
             args_num -= 1  # because of the self arg if exists
         return args_num, param_name
 
+    def _get_default_values(self) -> typing.List[typing.Any]:
+        # Returns a list of all variables' default values
+        return [arg.default for arg in self.args.values()]
+
 
 class Command:
     """
@@ -212,17 +219,19 @@ class Command:
         self.hidden = hidden
         self._checks = []
         self._raw_error_listener = None
+        self._raw_before_invoke = None
+        self._raw_after_invoke = None
         self.method_name: typing.Optional[str] = None
         self.parent: typing.Optional[typing.Any] = parent
         """The parent group for the command. If ``None`` then the command is not a subcommand."""
         self.plugin: typing.Optional[plugins.Plugin] = None
         """The plugin the command is registered to. If ``None`` then it was defined outside of a plugin."""
-        self.user_required_permissions: typing.Set[hikari.Permissions] = set()
+        self.user_required_permissions: hikari.Permissions = hikari.Permissions.NONE
         """
         The permissions required by a user to run the command. 
         These are extracted from the permission check decorator(s) on the command.
         """
-        self.bot_required_permissions: typing.Set[hikari.Permissions] = set()
+        self.bot_required_permissions: hikari.Permissions = hikari.Permissions.NONE
         """
         The permissions the bot requires for a user to be able to run the command. 
         These are extracted from the permission check decorator(s) on the command.
@@ -260,6 +269,18 @@ class Command:
             return getattr(self.plugin, self._raw_error_listener.__name__)
         return self._raw_error_listener
 
+    @functools.cached_property
+    def _before_invoke(self):
+        if self.plugin is not None and self._raw_before_invoke is not None:
+            return getattr(self.plugin, self._raw_before_invoke.__name__)
+        return self._raw_before_invoke
+
+    @functools.cached_property
+    def _after_invoke(self):
+        if self.plugin is not None and self._raw_after_invoke is not None:
+            return getattr(self.plugin, self._raw_after_invoke.__name__)
+        return self._raw_after_invoke
+
     @functools.cached_property
     def arg_details(self) -> SignatureInspector:
         """
@@ -303,7 +324,10 @@ class Command:
     def command_error(self):
         """
         A decorator to register a coroutine as the command's error handler. Any global error 
-        handler/listener for :obj:`~.errors.CommandErrorEvent` will still be called.
+        handler/listener for :obj:`~.events.CommandErrorEvent` will still be called.
+
+        The coroutine can only take one argument, which will be an instance of :obj:`~.events.CommandErrorEvent`
+        unless in a class in which case it may also take the ``self`` argument.
 
         Example:
 
@@ -322,18 +346,51 @@ class Command:
         """
 
         def decorate(
-            func: typing.Callable[[errors.CommandErrorEvent], typing.Coroutine[None, None, typing.Any]]
-        ) -> typing.Callable[[errors.CommandErrorEvent], typing.Coroutine[None, None, typing.Any]]:
+            func: typing.Callable[[events.CommandErrorEvent], typing.Coroutine[None, None, typing.Any]]
+        ) -> typing.Callable[[events.CommandErrorEvent], typing.Coroutine[None, None, typing.Any]]:
             self._raw_error_listener = func
             return func
 
         return decorate
 
+    def before_invoke(self):
+        """
+        A decorator to register a coroutine to be run before the command is invoked.
+
+        The coroutine can take only one argument which will be an instance of the :obj:`~.context.Context`
+        for the command.
+        """
+
+        def decorate(
+            func: typing.Callable[[context.Context], typing.Coroutine[None, None, typing.Any]]
+        ) -> typing.Callable[[context.Context], typing.Coroutine[None, None, typing.Any]]:
+            self._raw_before_invoke = func
+            return func
+
+        return decorate
+
+    def after_invoke(self):
+        """
+        A decorator to register a coroutine to be run after the command is invoked.
+
+        The coroutine can take only one argument which will be an instance of the :obj:`~.context.Context`
+        for the command.
+        """
+
+        def decorate(
+            func: typing.Callable[[context.Context], typing.Coroutine[None, None, typing.Any]]
+        ) -> typing.Callable[[context.Context], typing.Coroutine[None, None, typing.Any]]:
+            self._raw_after_invoke = func
+            return func
+
+        return decorate
+
     @staticmethod
     async def _convert_args(
         context: context.Context, args: typing.Sequence[str], arg_details: typing.Sequence[ArgInfo],
     ) -> typing.Sequence[typing.Any]:
         new_args = []
+
         for arg, details in zip(args, arg_details):
             arg = converters.WrappedArg(arg, context)
             if details.annotation is inspect.Parameter.empty or isinstance(details.annotation, str):
@@ -364,7 +421,9 @@ class Command:
         if self.cooldown_manager is not None:
             self.cooldown_manager.add_cooldown(context)
         # Add the start slice on to the length to offset the section of arg_details being extracted
-        new_args = await self._convert_args(context, args, list(self.arg_details.args.values())[1 : len(args) + 1])
+        arg_details = list(self.arg_details.args.values())[1 : len(args) + 1]
+        new_args = await self._convert_args(context, args[: len(arg_details)], arg_details)
+        new_args = [*new_args, *args[len(arg_details) :]]
         return await self._callback(context, *new_args, **kwargs)
 
     def add_check(self, check_func: typing.Callable[[context.Context], typing.Coroutine[None, None, bool]]) -> None:
