@@ -249,7 +249,7 @@ class HelpCommand:
             for c in sorted(commands, key=lambda c: c.name):
                 short_help = get_help_text(c).split("\n")[0]
                 help_text.append(f"> • `{c.name}` - {short_help}")
-        help_text.append(f"> \n> Use `{context.prefix}help [command]` for more information.")
+        help_text.append(f"> \n> Use `{context.clean_prefix}help [command]` for more information.")
         await self.send_paginated_help(help_text, context)
 
     async def send_plugin_help(self, context: context.Context, plugin: plugins.Plugin) -> None:
@@ -266,7 +266,7 @@ class HelpCommand:
         """
         help_text = [
             f"> **Help for category `{plugin.name}`**",
-            get_help_text(plugin) or "No help text provided.",
+            get_help_text(plugin).replace("\n", "\n> ") or "No help text provided.",
             f"Commands:",
             ", ".join(f"`{c.name}`" for c in sorted(plugin.commands.values(), key=lambda c: c.name))
             or "No commands in the category",
@@ -286,12 +286,12 @@ class HelpCommand:
             ``None``
         """
         help_text = [
-            f">**Help for command `{command.name}`**",
+            f"> **Help for command `{command.name}`**",
             f"Usage:",
-            f"```{context.prefix}{get_command_signature(command)}```",
-            get_help_text(command) or "No help text provided.",
+            f"```{context.clean_prefix}{get_command_signature(command)}```",
+            get_help_text(command).replace("\n", "\n> ") or "No help text provided.",
         ]
-        await context.reply("\n>".join(help_text))
+        await context.reply("\n> ".join(help_text))
 
     async def send_group_help(self, context: context.Context, group: commands.Group) -> None:
         """
@@ -308,8 +308,8 @@ class HelpCommand:
         help_text = [
             f"> **Help for command group `{group.name}`**",
             "Usage:",
-            f"```{context.prefix}{get_command_signature(group)}```",
-            get_help_text(group) or "No help text provided.",
+            f"```{context.clean_prefix}{get_command_signature(group)}```",
+            get_help_text(group).replace("\n", "\n> ") or "No help text provided.",
             f"Subcommands:" ", ".join(f"`{c.name}`" for c in sorted(group.subcommands, key=lambda c: c.name))
             or "No subcommands in the group",
         ]
